<div align="center">
    <img src="https://github.com/Spencerai/tscore/blob/master/pic/TAIScoreLogo.png" width="256px"/>
</div>

# TAIScore
   

## Install
via pip
```bash
pip install tscore
```

via source code
```bash
python setup.py install
```

## Usage
```python
import tscore as ts

```

## Documents
A simple API [docs](https://tscore.readthedocs.io/en/latest)

## Structure
- tscore.base  
base class and util function

- tscore.data  
get data and manage source data

- tscore.preprocessing  
data preprocessing  

- tscore.features  
feature engineering  

- tscore.score_card  
traditional logistic regression

- tscore.interpreter  
try to interpreter  black box model

- tscore.metrics  
model evalution

- tscore.model_selection  
model selection

- tscore.machine_learning  
score model with machine learning 

- tscore.pipeline  
pipeline build tools

- tscore.deploy  
    - generate model deoply file
    - api for model online  
    - hard rules for logistic regression score card rules

- tscore.plot  
visual model

- tscore.report  
generate report for credit score model

- tscore.risk_rules  
generate risk rules from data 

- tscore.monitor  
model monitor

## Authors
spencercs.ai@gmail.com